pub trait FlatError {
// Required method
fn error_variant(&self) -> &'static str;
}Expand description
Trait for errors that can report their variant name.
Required Methods
Sourcefn error_variant(&self) -> &'static str
fn error_variant(&self) -> &'static str
Returns the name of the error variant as a static string.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".