FlatError

Trait FlatError 

pub trait FlatError {
    // Required method
    fn error_variant(&self) -> &'static str;
}
Trait for errors that can report their variant name.

Required Methods

fn error_variant(&self) -> &'static str

Returns the name of the error variant as a static string.

Implementors